#!/bin/bash

# Automates the packaging process of the software "xorg-driver-s3virge" for
# use with Zenwalk Linux.
#	
# Copyright (C) 2009 Michael Verret <michael.verret@gmail.com>

# Summary:	S3 ViRGE video driver.
# Name:		xorg-driver-s3virge
# License:	MIT
# Group:	User Interface/X Hardware Support
# URL:		http://xorg.freedesktop.org/

# BuildRequires:

# Source:	http://xorg.freedesktop.org/releases/individual/driver/xf86-video-s3virge-1.10.2.tar.bz2:
#			or git clone git://anongit.freedesktop.org/xorg/driver/${Software_Name}


# Variables:
#_______________________________________________________________________



Source_Name="xf86-video-s3virge"
Software_Name="xorg-driver-s3virge"
Source_Version="1.10.2"
Software_Version="${Source_Version}"
Release="60"
Build="1"

Flag_Arch='i486'
Flag_Tune='i686'
Package_Arch="${Flag_Arch}"

Special_Docs=" "
Standard_Docs="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"
	
Build_Root=$(pwd)
Package="${Software_Name}-${Software_Version}-${Package_Arch}-${Release}.${Build}"
Installation_Root="${Build_Root}/${Package}"

Sources=" \
	${Source_Name}-${Source_Version}.tar.bz2"
Patches=" "
Scripts=" \
	build-${Software_Name}.sh"
Miscellaneous=" \
	s3virge.xinf"	
Build_Root=$(pwd)



# Clean & prep:
#_______________________________________________________________________



# Remove cruft and create Installation_Root
	rm -rf ${Package}* ${Package}-src* 1>/dev/null 2>&1
	mkdir ${Installation_Root}
# Check for necessary files:
	for File in ${Sources} ${Patches} ${Scripts} ${Miscellaneous} ; do
		echo -n "${File} :"
		if [ -e ${File} ]; then
			echo " OK"
		else
			echo " MISSING !"
			exit 1
		fi
	done
# Add A Package Description File:
mkdir -p ${Installation_Root}/install
cat <<EOF0 > ${Installation_Root}/install/slack-desc 
                   |-----handy-ruler------------------------------------------------------|
xorg-driver-s3virge: xorg-driver-s3virge (S3 ViRGE video driver)
xorg-driver-s3virge:
xorg-driver-s3virge: This package provides the driver for the S3 ViRGE and
xorg-driver-s3virge: Trio3D family of chipsets. It does not support Trio64
xorg-driver-s3virge: or S3 96x cards; support for these can be found in
xorg-driver-s3virge: the xf86-video-s3 package. Support for S3 Savage
xorg-driver-s3virge: chipsets can be found in xf86-video-savage.
xorg-driver-s3virge:
xorg-driver-s3virge:
xorg-driver-s3virge:
xorg-driver-s3virge:
xorg-driver-s3virge:
EOF0
# Install build-scripts patches and miscellaneous items:
	mkdir -p ${Installation_Root}/usr/src/${Software_Name}-${Software_Version}
	cp ${Patches} ${Scripts} ${Miscellaneous} \
	${Installation_Root}/usr/src/${Software_Name}-${Software_Version}/


# Build:
#_______________________________________________________________________



for File in ${Sources} ; do
	Source_Dir="$(basename ${File} .tar.bz2)"
	rm -rf ${Source_Dir}
	tar jxvf ${File}
	cd ${Source_Dir}
# Ensure proper permissions and ownership:
	chown -R root:root .
	find . -perm 666 -exec chmod 644 {} \;
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
# Configuration:
	./configure \
	CFLAGS="-O2 -march=${Flag_Arch} -mtune=${Flag_Tune}" \
	CXXFLAGS="${CFLAGS}" \
	PKG_CONFIG_PATH=/usr/lib/pkgconfig \
	--prefix=/usr \
	--bindir=/usr/bin \
	--sbindir=/usr/sbin \
	--libexecdir=/usr/libexec \
	--sysconfdir=/etc \
	--sharedstatedir=/usr/com \
	--localstatedir=/var \
	--libdir=/usr/lib \
	--includedir=/usr/include \
	--oldincludedir=/usr/include \
	--infodir=/usr/info \
	--mandir=/usr/man \
	--silent
# Compilation:
	make --silent || exit 1
	make check || exit 1
# Installation:
	make install --silent  DESTDIR=${Installation_Root} || exit 1
# Documentation:
	mkdir -p ${Installation_Root}/usr/doc/${Source_Dir}/
	for Doc in {${Standard_Docs},${Special_Docs}} ; do
		if [ -e ${Doc} ] ; then
			cp ${Doc} ${Installation_Root}/usr/doc/${Source_Dir}/
		fi
	done
	(
		cd ${Installation_Root}/usr/doc/${Source_Dir}/
		find . -name "*" -size 0c -exec rm {} \;
	)
# Post-build Cleanup:
	cd ${Build_Root}
	rm -rf ${Source_Dir}
done


# Special Routines:
#_______________________________________________________________________



	mkdir -p ${Installation_Root}/usr/share/hwdata/videoaliases
	install -m 0644 s3virge.xinf ${Installation_Root}/usr/share/hwdata/videoaliases/



# Packaging:
#_______________________________________________________________________



# Strip binaries:
	(
		cd ${Installation_Root}
		find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
		find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
	)
# Compress the man pages.
	if [ -d ${Installation_Root}/usr/man ]; then
	(
		cd ${Installation_Root}/usr/man
		gzip -9 */*
	)
	fi
# Create dep file:
	(
		cd ${Installation_Root}
		requiredbuilder -z ${Installation_Root} >> ${Build_Root}/${Package}.dep
	)
# Compress the package:
    (
      cd ${Installation_Root}
      makepkg -l y -c n ${Build_Root}/${Package}.tgz
    )
# Calculate the MD5 sum:
    cd ${Build_Root}
      md5sum ${Package}.tgz > ${Package}.md5
# Create a source package and checksum:
	mkdir ${Package}-src
	cp  ${Sources} ${Patches} ${Scripts} ${Miscellaneous} \
		${Package}-src
	tar jcf ${Package}-src.tar.bz2 ${Package}-src
	md5sum ${Package}-src.tar.bz2 > ${Package}-src.md5
# Post-build cleanup:
	rm -rf ${Installation_Root} ${Package}-src



# Changelog:
#_______________________________________________________________________



# ~ Wed Feb 4th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: xorg-driver-s3virge-1.10.2
# ~ Build 60.1
